@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
-// $Id: Delaunay_triangulation_2.h d1a323c 2020-03-26T19:24:14+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
+// $Id: Delaunay_triangulation_2.h fbe559a 2023-02-14T08:32:33+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mariette Yvinec
@@ -88,7 +88,7 @@ public:
   Delaunay_triangulation_2(
          const Delaunay_triangulation_2<Gt,Tds> &tr)
        : Triangulation_2<Gt,Tds>(tr)
-  {   CGAL_triangulation_postcondition(is_valid());  }
+  {   CGAL_postcondition(is_valid());  }
 
   Delaunay_triangulation_2(Delaunay_triangulation_2&&) = default;
   Delaunay_triangulation_2& operator=(const Delaunay_triangulation_2&) = default;
@@ -193,7 +193,7 @@ private:
   void propagating_flip(const Face_handle& f,int i);
 #endif
 
-// auxilliary functions for remove
+// auxiliary functions for remove
   void remove_degree_init(Vertex_handle v, std::vector<Face_handle> &f,
          std::vector<Vertex_handle> &w, std::vector<int> &i,int&d,int&maxd);
   void remove_degree_triangulate(Vertex_handle v, std::vector<Face_handle> &f,
@@ -269,7 +269,7 @@ private:
          std::vector<Vertex_handle> &w, std::vector<int> &i);
   void remove_degree7_rightfan  (Vertex_handle&,int,std::vector<Face_handle> &f,
          std::vector<Vertex_handle> &w, std::vector<int> &i);
-// end of auxilliary functions for remove
+// end of auxiliary functions for remove
 
   Vertex_handle nearest_vertex_2D(const Point& p, Face_handle f) const;
   Vertex_handle nearest_vertex_1D(const Point& p) const;
@@ -300,12 +300,12 @@ public:
   template < class InputIterator >
   std::ptrdiff_t
   insert(InputIterator first, InputIterator last,
-         typename boost::enable_if<
-         boost::is_convertible<
-         typename std::iterator_traits<InputIterator>::value_type,
-         Point
-         >
-         >::type* = nullptr)
+         std::enable_if_t<
+           boost::is_convertible<
+             typename std::iterator_traits<InputIterator>::value_type,
+             Point
+           >::value
+         >* = nullptr)
 #else
   template < class InputIterator >
   std::ptrdiff_t
@@ -358,10 +358,8 @@ private:
       it = indices.begin(), end = indices.end();
       it != end; ++it) {
       v_hint = insert(points[*it], hint);
-      if(v_hint!=Vertex_handle()) {
-        v_hint->info()=infos[*it];
-        hint=v_hint->face();
-      }
+      v_hint->info()=infos[*it];
+      hint=v_hint->face();
     }
 
     return this->number_of_vertices() - n;
@@ -373,11 +371,11 @@ public:
   std::ptrdiff_t
   insert(InputIterator first,
          InputIterator last,
-         typename boost::enable_if<
+         std::enable_if_t<
            boost::is_convertible<
              typename std::iterator_traits<InputIterator>::value_type,
              std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type>
-           > >::type* = nullptr)
+           >::value >* = nullptr)
   {
     return insert_with_info< std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type> >(first,last);
   }
@@ -386,12 +384,12 @@ public:
   std::ptrdiff_t
   insert(boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
          boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
-         typename boost::enable_if<
+         std::enable_if_t<
            boost::mpl::and_<
              boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
              boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
-           >
-         >::type* = nullptr)
+           >::value
+         >* = nullptr)
   {
     return insert_with_info< boost::tuple<Point,typename internal::Info_check<typename Tds::Vertex>::type> >(first,last);
   }
@@ -404,7 +402,7 @@ public:
                              OutputItBoundaryEdges eit,
                              Face_handle start = Face_handle()) const
   {
-    CGAL_triangulation_precondition(this->dimension() == 2);
+    CGAL_precondition(this->dimension() == 2);
     int li;
     Locate_type lt;
     Face_handle fh = this->locate(p,lt,li, start);
@@ -422,7 +420,7 @@ public:
         pit = propagate_conflicts(p,fh,2,pit);
         return pit;
     }
-    CGAL_triangulation_assertion(false);
+    CGAL_assertion(false);
     return std::make_pair(fit,eit);
   }
 
@@ -674,7 +672,7 @@ is_valid(bool verbose, int level) const
         result = result && ON_POSITIVE_SIDE !=
             side_of_oriented_circle(it, this->mirror_vertex(it,i)->point(), false);
       }
-      CGAL_triangulation_assertion(result);
+      CGAL_assertion(result);
     }
   }
   return result;
@@ -705,7 +703,7 @@ typename Delaunay_triangulation_2<Gt,Tds>::Vertex_handle
 Delaunay_triangulation_2<Gt,Tds>::
 nearest_vertex_2D(const Point& p, Face_handle f) const
 {
-  CGAL_triangulation_precondition(this->dimension() == 2);
+  CGAL_precondition(this->dimension() == 2);
   f = this->locate(p,f);
 
   typename Geom_traits::Compare_distance_2
@@ -775,8 +773,8 @@ typename Delaunay_triangulation_2<Gt,Tds>::Point
 Delaunay_triangulation_2<Gt,Tds>::
 dual(Face_handle f) const
 {
-  CGAL_triangulation_precondition(this->_tds.is_face(f));
-  CGAL_triangulation_precondition(this->dimension()==2);
+  CGAL_precondition(this->_tds.is_face(f));
+  CGAL_precondition(this->dimension()==2);
   return circumcenter(f);
 }
 
@@ -785,12 +783,12 @@ Object
 Delaunay_triangulation_2<Gt,Tds>::
 dual(const Edge &e) const
 {
-  CGAL_triangulation_precondition(this->_tds.is_edge(e.first,e.second));
+  CGAL_precondition(this->_tds.is_edge(e.first,e.second));
 
   typedef typename Geom_traits::Line_2        Line;
   typedef typename Geom_traits::Ray_2         Ray;
 
-  CGAL_triangulation_precondition (!this->is_infinite(e));
+  CGAL_precondition (!this->is_infinite(e));
   if(this->dimension()== 1) {
     const Point& p = (e.first)->vertex(cw(e.second))->point();
     const Point& q = (e.first)->vertex(ccw(e.second))->point();
@@ -1031,8 +1029,8 @@ void
 Delaunay_triangulation_2<Gt,Tds>::
 remove_and_give_new_faces(Vertex_handle v, OutputItFaces fit)
 {
-  CGAL_triangulation_precondition(v != Vertex_handle());
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(v != Vertex_handle());
+  CGAL_precondition(!this->is_infinite(v));
 
   if(this->number_of_vertices() == 1) this->remove_first(v);
   else if(this->number_of_vertices() == 2) this->remove_second(v);
@@ -1071,8 +1069,8 @@ remove(Vertex_handle v)
 {
   int d;
 
-  CGAL_triangulation_precondition(v != Vertex_handle());
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(v != Vertex_handle());
+  CGAL_precondition(!this->is_infinite(v));
 
   if(this->dimension() <= 1) { Triangulation::remove(v); return; }
 
@@ -2119,7 +2117,7 @@ typename Delaunay_triangulation_2<Gt,Tds>::Vertex_handle
 Delaunay_triangulation_2<Gt,Tds>::
 move_if_no_collision(Vertex_handle v, const Point &p)
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(!this->is_infinite(v));
   if(v->point() == p) return v;
   const int dim = this->dimension();
 
@@ -2167,7 +2165,7 @@ move_if_no_collision(Vertex_handle v, const Point &p)
       Face_handle f = v->face();
       int i = f->index(v);
       if(i==0) {f = f->neighbor(1);}
-      CGAL_triangulation_assertion(f->index(v) == 1);
+      CGAL_assertion(f->index(v) == 1);
       Face_handle g= f->neighbor(0);
       f->set_vertex(1, g->vertex(1));
       f->set_neighbor(0,g->neighbor(0));
@@ -2177,7 +2175,7 @@ move_if_no_collision(Vertex_handle v, const Point &p)
       Face_handle f_ins = inserted->face();
       i = f_ins->index(inserted);
       if(i==0) {f_ins = f_ins->neighbor(1);}
-      CGAL_triangulation_assertion(f_ins->index(inserted) == 1);
+      CGAL_assertion(f_ins->index(inserted) == 1);
       Face_handle g_ins = f_ins->neighbor(0);
       f_ins->set_vertex(1, v);
       g_ins->set_vertex(0, v);
@@ -2249,7 +2247,7 @@ typename Delaunay_triangulation_2<Gt,Tds>::Vertex_handle
 Delaunay_triangulation_2<Gt,Tds>::
 move(Vertex_handle v, const Point &p)
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(!this->is_infinite(v));
   if(v->point() == p) return v;
   Vertex_handle w = move_if_no_collision(v,p);
   if(w != v) {
@@ -2264,9 +2262,9 @@ bool
 Delaunay_triangulation_2<Gt,Tds>::
 is_delaunay_after_displacement(Vertex_handle v, const Point &p) const
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
-  CGAL_triangulation_precondition(this->dimension() == 2);
-  CGAL_triangulation_precondition(!this->test_dim_down(v));
+  CGAL_precondition(!this->is_infinite(v));
+  CGAL_precondition(this->dimension() == 2);
+  CGAL_precondition(!this->test_dim_down(v));
   if(v->point() == p) return true;
   Point ant = v->point();
   v->set_point(p);
@@ -2320,7 +2318,7 @@ move_if_no_collision_and_give_new_faces(Vertex_handle v,
                                         const Point &p,
                                         OutputItFaces oif)
 {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(!this->is_infinite(v));
   if(v->point() == p) return v;
 
   const int dim = this->dimension();
@@ -2374,7 +2372,7 @@ move_if_no_collision_and_give_new_faces(Vertex_handle v,
       Face_handle f = v->face();
       int i = f->index(v);
       if(i==0) {f = f->neighbor(1);}
-      CGAL_triangulation_assertion(f->index(v) == 1);
+      CGAL_assertion(f->index(v) == 1);
       Face_handle g= f->neighbor(0);
       f->set_vertex(1, g->vertex(1));
       f->set_neighbor(0,g->neighbor(0));
@@ -2385,7 +2383,7 @@ move_if_no_collision_and_give_new_faces(Vertex_handle v,
       Face_handle f_ins = inserted->face();
       i = f_ins->index(inserted);
       if(i==0) {f_ins = f_ins->neighbor(1);}
-      CGAL_triangulation_assertion(f_ins->index(inserted) == 1);
+      CGAL_assertion(f_ins->index(inserted) == 1);
       Face_handle g_ins = f_ins->neighbor(0);
       f_ins->set_vertex(1, v);
       g_ins->set_vertex(0, v);
@@ -2470,3 +2468,4 @@ move_if_no_collision_and_give_new_faces(Vertex_handle v,
 } //namespace CGAL
 
 #endif // CGAL_DELAUNAY_TRIANGULATION_2_H
+
