@@ -6,8 +6,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Mesh_3/include/CGAL/Mesh_3/Slivers_exuder.h $
-// $Id: Slivers_exuder.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_3/Slivers_exuder.h $
+// $Id: Slivers_exuder.h 532b82c 2023-05-04T17:28:47+02:00 Mael
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -158,7 +158,7 @@ protected:
   }
 
   /**
-   * A functor to remove one \c Cell_handle from a priority queue
+   * A functor to remove one `Cell_handle` from a priority queue
    */
   class Erase_from_queue
   {
@@ -173,7 +173,7 @@ protected:
   };
 
   /**
-   * Delete cells of \c cells from \c cells_queue
+   * Deletes cells of `cells` from `cells_queue`.
    */
   void delete_cells_from_queue(const Cell_vector& cells)
   {
@@ -289,7 +289,7 @@ protected:
   }
 
   /**
-   * A functor to remove one \c Cell_handle from a priority queue
+   * A functor to remove one `Cell_handle` from a priority queue
    */
   class Erase_from_queue
   {
@@ -301,7 +301,7 @@ protected:
   };
 
   /**
-   * Delete cells of \c cells from \c cells_queue
+   * Deletes cells of `cells` from `cells_queue`.
    */
   void delete_cells_from_queue(const Cell_vector& cells)
   {
@@ -526,7 +526,7 @@ private:
                                const Vertex_handle& new_vertex);
 
   /**
-   * Orders handles \c h1 & \c h2
+   * Orders handles `h1` & `h2`
    */
   template <typename Handle>
   static
@@ -564,7 +564,7 @@ private:
 
 
   /**
-   * Initialize cells_queue w.r.t sliver_bound_
+   * Initialize cells_queue w.r.t. sliver_bound_
    */
   void initialize_cells_priority_queue()
   {
@@ -595,8 +595,8 @@ private:
 
 
   /**
-   * Returns the \c Boundary_facets_from_outside object containing mirror facets
-   * of \c facets
+   * Returns the `Boundary_facets_from_outside` object containing mirror facets
+   * of `facets`.
    */
   Boundary_facets_from_outside
   get_boundary_facets_from_outside(const Facet_vector& facets) const
@@ -617,7 +617,7 @@ private:
   }
 
   /**
-   * Add a cell \c ch to \c cells_queue
+   * Adds a cell `ch` to `cells_queue`.
    */
   template <bool pump_vertices_on_surfaces>
   void add_cell_to_queue(Cell_handle ch, FT criterion_value)
@@ -652,7 +652,7 @@ private:
   };
 
   /**
-   * Removes objects of [begin,end[ range from \c c3t3_
+   * Removes objects of [begin,end[ range from `c3t3_`.
    */
   template<typename ForwardIterator>
   void remove_from_c3t3(ForwardIterator begin, ForwardIterator end)
@@ -853,8 +853,8 @@ private:
                       const Vertex_handle& vh) const;
 
   /**
-   * Checks if the sliver criterion values from \c criterion_values are the same as
-   * those that will be found if wp is inserted in the triangulation
+   * Checks if the sliver criterion values from `criterion_values` are the same as
+   * those that will be found if wp is inserted in the triangulation.
    */
   bool check_ratios(const Sliver_values& criterion_values,
                     const Weighted_point& wp,
@@ -965,9 +965,9 @@ pump_vertices(FT sliver_criterion_limit,
       bool vertex_pumped = false;
       for( int i = 0; i < 4; ++i )
       {
-        // pump_vertices_on_surfaces is a boolean template parameter.  The
-        // following condition is pruned at compiled time, if
-        // pump_vertices_on_surfaces==false.
+        // pump_vertices_on_surfaces is a Boolean template parameter.
+        // The following condition is pruned at compile time,
+        // if pump_vertices_on_surfaces is `false`.
         if( pump_vertices_on_surfaces || c3t3_.in_dimension(c->vertex(i)) > 2 )
         {
           if( pump_vertex<pump_vertices_on_surfaces>(c->vertex(i)) )
@@ -977,7 +977,9 @@ pump_vertices(FT sliver_criterion_limit,
             break;
           }
           else
+          {
             ++num_of_ignored_vertices_;
+          }
 
           ++num_of_treated_vertices_;
         }
@@ -988,14 +990,14 @@ pump_vertices(FT sliver_criterion_limit,
         this->cells_queue_pop_front();
 
       visitor.after_cell_pumped(this->cells_queue_size());
-  #ifdef CGAL_MESH_3_EXUDER_VERBOSE
+#ifdef CGAL_MESH_3_EXUDER_VERBOSE
       Rcpp::Rcerr << boost::format("\r             \r"
                                  "(%1%,%2%,%3%) (%|4$.1f| vertices/s)")
         % this->cells_queue_size()
         % num_of_pumped_vertices_
         % num_of_ignored_vertices_
         % (num_of_treated_vertices_ / running_time_.time());
-  #endif // CGAL_MESH_3_EXUDER_VERBOSE
+#endif // CGAL_MESH_3_EXUDER_VERBOSE
     }
   }
 
@@ -1055,12 +1057,12 @@ pump_vertex(const Vertex_handle& pumped_vertex,
   {
     typename Gt::Construct_point_3 cp = tr_.geom_traits().construct_point_3_object();
 
-    const Weighted_point& pwp = tr_.point(pumped_vertex);
-    Weighted_point wp(cp(pwp), best_weight);
+    const Weighted_point& old_position = tr_.point(pumped_vertex);
+    Weighted_point new_point(cp(old_position), best_weight);
 
     // Insert weighted point into mesh
     // note it can fail if the mesh is non-manifold at pumped_vertex
-    return update_mesh<pump_vertices_on_surfaces>(wp,
+    return update_mesh<pump_vertices_on_surfaces>(new_point,
                                                   pumped_vertex,
                                                   could_lock_zone);
   }
@@ -1560,7 +1562,7 @@ update_mesh(const Weighted_point& new_point,
   if (could_lock_zone && *could_lock_zone == false)
     return false;
 
-  // Get some datas to restore mesh
+  // Get some data to restore mesh
   Boundary_facets_from_outside boundary_facets_from_outside =
     get_boundary_facets_from_outside(boundary_facets);
 
@@ -1873,3 +1875,4 @@ check_ratios(const Sliver_values& criterion_values,
 
 #include <CGAL/enable_warnings.h>
 #endif // end CGAL_MESH_3_SLIVERS_EXUDER_H
+
