@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Optimisation_basic/include/CGAL/Optimisation/basic.h $
-// $Id: basic.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Optimisation_basic/include/CGAL/Optimisation/basic.h $
+// $Id: basic.h 74e4d89 2022-09-27T10:42:05+01:00 Andreas Fabri
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,7 +19,6 @@
 
 // includes
 #include <CGAL/basic.h>
-#include <CGAL/Optimisation/assertions.h>
 #include <CGAL/Optimisation/debug.h>
 #include <CGAL/IO/Verbose_ostream.h>
 
@@ -43,3 +42,4 @@ _optimisation_is_valid_fail( CGAL::Verbose_ostream& verr,
 } //namespace CGAL
 
 #endif // CGAL_OPTIMISATION_BASIC_H
+
