@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Partition_2/include/CGAL/Partition_2/partition_greene_approx_convex_2.h $
-// $Id: partition_greene_approx_convex_2.h 521c72d 2021-10-04T13:22:00+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Partition_2/include/CGAL/Partition_2/partition_greene_approx_convex_2.h $
+// $Id: partition_greene_approx_convex_2.h 1ad69e0 2022-09-27T08:32:49+01:00 Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,7 +24,7 @@
 #include<CGAL/Partition_2/partition_y_monotone_2.h>
 #include<CGAL/Partition_2/Turn_reverser.h>
 #include<CGAL/IO/Tee_for_output_iterator.h>
-#include<CGAL/Partition_2/partition_assertions.h>
+#include<CGAL/assertions.h>
 #include<CGAL/partition_is_valid_2.h>
 #include<CGAL/Partition_traits_2.h>
 #include<CGAL/is_y_monotone_2.h>
@@ -91,7 +91,7 @@ void erase_vertices(BidirectionalCirculator first,
 #endif
    it = first.current_iterator();
 
-   CGAL_partition_assertion (it != polygon.end());
+   CGAL_assertion (it != polygon.end());
 
    while ( (it != polygon.end()) && (*it != *last) )
    {
@@ -693,9 +693,9 @@ void ga_convex_decomposition(ForwardIterator first, ForwardIterator beyond,
 
    Vertex_list  polygon(first, beyond);
 
-   CGAL_partition_precondition(
+   CGAL_precondition(
     orientation_2(polygon.begin(), polygon.end(), traits) == COUNTERCLOCKWISE);
-   CGAL_partition_precondition(
+   CGAL_precondition(
     is_y_monotone_2(polygon.begin(), polygon.end(), traits));
 
    Vertex_circulator point_ref(&polygon);
@@ -807,7 +807,7 @@ OutputIterator partition_greene_approx_convex_2(InputIterator first,
 #endif // no postconditions
 
    Polygon_2  polygon(first, beyond);
-   CGAL_partition_precondition(
+   CGAL_precondition(
       orientation_2(polygon.vertices_begin(), polygon.vertices_end(),
                                                traits) == COUNTERCLOCKWISE);
 
@@ -823,7 +823,7 @@ OutputIterator partition_greene_approx_convex_2(InputIterator first,
                               (*MP_it).vertices_end(), res, traits);
    }
 
-   CGAL_partition_postcondition(
+   CGAL_postcondition(
        convex_partition_is_valid_2(polygon.vertices_begin(),
                                    polygon.vertices_end(),
                                    res.output_so_far_begin(),
@@ -852,3 +852,4 @@ OutputIterator partition_greene_approx_convex_2(InputIterator first,
 }
 
 #endif // CGAL_GREENE_APPROX_H
+
